#!/usr/bin/env python
"""Contains utilities supporting schematic processor tools.

ArcGIS Version:  10
Author:  Tim Whiteaker

"""

import os
import sys

import arcpy

def check_field(field_list, field_name):
    """Returns True if field list has a field with the given name.

    Arguments:
        field_list -- list of fields
        field_name -- name of the field to search for

    """

    for field in field_list:
        if field.name.lower() == field_name.lower():
            return True

    return False


def get_path():
    """Returns the path to this module."""
    return os.path.dirname(__file__)


def get_module(module_name):
    """Returns a module object.  Imports the module if not initially found."""
    if not module_name in sys.modules:
        exec('import %s' % module_name)
    return sys.modules[module_name]


def split_multivalue(multivalue):
    """Returns list of items from multivalue geoprocessing input.

    Arguments:
        multivalue -- multivalue input from arcpy.GetParameterAsText()
    Remarks:
        If multivalue is empty, an empty list is returned.

    """

    if multivalue == '':
        return []
    else:
        return multivalue.split(';')


def add_gp_message(message, severity=0):
    """Adds and prints a GPMessage.

    Adds a GPMessage (for the case when run as an ArcToolbox tool)
    and also prints the message to the screen (standard output).

    Arguments:
        message -- the message to add and print
        severity -- indicates severity of GPMessage
            0 = message
            1 = warning
            2 = error
            
    """
    
    print message
    
    # Split the message on \n first, so that if it's multiple lines, 
    # a GPMessage will be added for each line
    try:
        for string in message.split('\n'):
            # Add appropriate geoprocessing message 
            if severity == 0:
                arcpy.AddMessage(string)
            elif severity == 1:
                arcpy.AddWarning(string)
            elif severity == 2:
                arcpy.AddError(string)
    except Exception as e:
        pass
 
